import pytest

from quacc import SETTINGS, flow, job, subflow

redun = pytest.importorskip("redun")
pytestmark = pytest.mark.skipif(
    SETTINGS.WORKFLOW_ENGINE != "redun",
    reason="This test requires the Redun workflow engine",
)


@pytest.fixture()
def scheduler():
    return redun.Scheduler()


def test_redun_decorators(tmp_path, monkeypatch, scheduler):
    monkeypatch.chdir(tmp_path)

    @job
    def add(a, b):
        return a + b

    @job
    def mult(a, b):
        return a * b

    @job
    def make_more(val):
        return [val] * 3

    @subflow
    def add_distributed(vals, c):
        return [add(val, c) for val in vals]

    @flow
    def workflow(a, b, c):
        return mult(add(a, b), c)

    @flow
    def dynamic_workflow(a, b, c):
        result1 = add(a, b)
        result2 = make_more(result1)
        return add_distributed(result2, c)

    assert scheduler.run(add(1, 2)) == 3
    assert scheduler.run(mult(1, 2)) == 2
    assert scheduler.run(workflow(1, 2, 3)) == 9
    assert scheduler.run(dynamic_workflow(1, 2, 3)) == [6, 6, 6]
